@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2022
+# Copyright (C) 2015-2023
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -18,7 +18,7 @@
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 """This module contains the classes that represent Telegram InlineQueryResultLocation."""
 
-from typing import TYPE_CHECKING, ClassVar
+from typing import TYPE_CHECKING, Final, Optional
 
 from telegram import constants
 from telegram._inline.inlinekeyboardmarkup import InlineKeyboardMarkup
@@ -35,6 +35,9 @@ class InlineQueryResultLocation(InlineQueryResult):
     Alternatively, you can use :attr:`input_message_content` to send a message with the specified
     content instead of the location.
 
+    .. versionchanged:: 20.5
+        |removed_thumb_wildcard_note|
+
     Args:
         id (:obj:`str`): Unique identifier for this result,
             :tg-const:`telegram.InlineQueryResult.MIN_ID_LENGTH`-
@@ -62,9 +65,15 @@ class InlineQueryResultLocation(InlineQueryResult):
             to the message.
         input_message_content (:class:`telegram.InputMessageContent`, optional): Content of the
             message to be sent instead of the location.
-        thumb_url (:obj:`str`, optional): Url of the thumbnail for the result.
-        thumb_width (:obj:`int`, optional): Thumbnail width.
-        thumb_height (:obj:`int`, optional): Thumbnail height.
+        thumbnail_url (:obj:`str`, optional): Url of the thumbnail for the result.
+
+            .. versionadded:: 20.2
+        thumbnail_width (:obj:`int`, optional): Thumbnail width.
+
+            .. versionadded:: 20.2
+        thumbnail_height (:obj:`int`, optional): Thumbnail height.
+
+            .. versionadded:: 20.2
 
     Attributes:
         type (:obj:`str`): :tg-const:`telegram.constants.InlineQueryResultType.LOCATION`.
@@ -94,17 +103,23 @@ class InlineQueryResultLocation(InlineQueryResult):
             to the message.
         input_message_content (:class:`telegram.InputMessageContent`): Optional. Content of the
             message to be sent instead of the location.
-        thumb_url (:obj:`str`): Optional. Url of the thumbnail for the result.
-        thumb_width (:obj:`int`): Optional. Thumbnail width.
-        thumb_height (:obj:`int`): Optional. Thumbnail height.
+        thumbnail_url (:obj:`str`): Optional. Url of the thumbnail for the result.
+
+            .. versionadded:: 20.2
+        thumbnail_width (:obj:`int`): Optional. Thumbnail width.
+
+            .. versionadded:: 20.2
+        thumbnail_height (:obj:`int`): Optional. Thumbnail height.
+
+            .. versionadded:: 20.2
 
     """
 
     __slots__ = (
         "longitude",
         "reply_markup",
-        "thumb_width",
-        "thumb_height",
+        "thumbnail_width",
+        "thumbnail_height",
         "heading",
         "title",
         "live_period",
@@ -112,7 +127,7 @@ class InlineQueryResultLocation(InlineQueryResult):
         "input_message_content",
         "latitude",
         "horizontal_accuracy",
-        "thumb_url",
+        "thumbnail_url",
     )
 
     def __init__(
@@ -121,69 +136,69 @@ class InlineQueryResultLocation(InlineQueryResult):
         latitude: float,
         longitude: float,
         title: str,
-        live_period: int = None,
-        reply_markup: InlineKeyboardMarkup = None,
-        input_message_content: "InputMessageContent" = None,
-        thumb_url: str = None,
-        thumb_width: int = None,
-        thumb_height: int = None,
-        horizontal_accuracy: float = None,
-        heading: int = None,
-        proximity_alert_radius: int = None,
+        live_period: Optional[int] = None,
+        reply_markup: Optional[InlineKeyboardMarkup] = None,
+        input_message_content: Optional["InputMessageContent"] = None,
+        horizontal_accuracy: Optional[float] = None,
+        heading: Optional[int] = None,
+        proximity_alert_radius: Optional[int] = None,
+        thumbnail_url: Optional[str] = None,
+        thumbnail_width: Optional[int] = None,
+        thumbnail_height: Optional[int] = None,
         *,
-        api_kwargs: JSONDict = None,
+        api_kwargs: Optional[JSONDict] = None,
     ):
         # Required
         super().__init__(constants.InlineQueryResultType.LOCATION, id, api_kwargs=api_kwargs)
         with self._unfrozen():
-            self.latitude = latitude
-            self.longitude = longitude
-            self.title = title
+            self.latitude: float = latitude
+            self.longitude: float = longitude
+            self.title: str = title
 
             # Optionals
-            self.live_period = live_period
-            self.reply_markup = reply_markup
-            self.input_message_content = input_message_content
-            self.thumb_url = thumb_url
-            self.thumb_width = thumb_width
-            self.thumb_height = thumb_height
-            self.horizontal_accuracy = horizontal_accuracy
-            self.heading = heading
-            self.proximity_alert_radius = (
+            self.live_period: Optional[int] = live_period
+            self.reply_markup: Optional[InlineKeyboardMarkup] = reply_markup
+            self.input_message_content: Optional[InputMessageContent] = input_message_content
+            self.thumbnail_url: Optional[str] = thumbnail_url
+            self.thumbnail_width: Optional[int] = thumbnail_width
+            self.thumbnail_height: Optional[int] = thumbnail_height
+            self.horizontal_accuracy: Optional[float] = horizontal_accuracy
+            self.heading: Optional[int] = heading
+            self.proximity_alert_radius: Optional[int] = (
                 int(proximity_alert_radius) if proximity_alert_radius else None
             )
 
-    HORIZONTAL_ACCURACY: ClassVar[int] = constants.LocationLimit.HORIZONTAL_ACCURACY
+    HORIZONTAL_ACCURACY: Final[int] = constants.LocationLimit.HORIZONTAL_ACCURACY
     """:const:`telegram.constants.LocationLimit.HORIZONTAL_ACCURACY`
 
     .. versionadded:: 20.0
     """
-    MIN_HEADING: ClassVar[int] = constants.LocationLimit.MIN_HEADING
+    MIN_HEADING: Final[int] = constants.LocationLimit.MIN_HEADING
     """:const:`telegram.constants.LocationLimit.MIN_HEADING`
 
     .. versionadded:: 20.0
     """
-    MAX_HEADING: ClassVar[int] = constants.LocationLimit.MAX_HEADING
+    MAX_HEADING: Final[int] = constants.LocationLimit.MAX_HEADING
     """:const:`telegram.constants.LocationLimit.MAX_HEADING`
 
     .. versionadded:: 20.0
     """
-    MIN_LIVE_PERIOD: ClassVar[int] = constants.LocationLimit.MIN_LIVE_PERIOD
+    MIN_LIVE_PERIOD: Final[int] = constants.LocationLimit.MIN_LIVE_PERIOD
     """:const:`telegram.constants.LocationLimit.MIN_LIVE_PERIOD`
 
     .. versionadded:: 20.0
     """
-    MAX_LIVE_PERIOD: ClassVar[int] = constants.LocationLimit.MAX_LIVE_PERIOD
+    MAX_LIVE_PERIOD: Final[int] = constants.LocationLimit.MAX_LIVE_PERIOD
     """:const:`telegram.constants.LocationLimit.MAX_LIVE_PERIOD`
 
     .. versionadded:: 20.0
     """
-    MIN_PROXIMITY_ALERT_RADIUS: ClassVar[int] = constants.LocationLimit.MIN_PROXIMITY_ALERT_RADIUS
+    MIN_PROXIMITY_ALERT_RADIUS: Final[int] = constants.LocationLimit.MIN_PROXIMITY_ALERT_RADIUS
     """:const:`telegram.constants.LocationLimit.MIN_PROXIMITY_ALERT_RADIUS`
 
     .. versionadded:: 20.0
     """
-    MAX_PROXIMITY_ALERT_RADIUS: ClassVar[int] = constants.LocationLimit.MAX_PROXIMITY_ALERT_RADIUS
+    MAX_PROXIMITY_ALERT_RADIUS: Final[int] = constants.LocationLimit.MAX_PROXIMITY_ALERT_RADIUS
     """:const:`telegram.constants.LocationLimit.MAX_PROXIMITY_ALERT_RADIUS`
 
     .. versionadded:: 20.0
